Module let_engine::data

source ·
Holds model related data structures like Vertices and premade models as well as a circle maker macro.

Macros

  • A macro that makes it easy to create circles.

Structs

  • Vertex and index data for the appearance and shape of objects. Has 3 simple presets.

Constants

Functions

  • Creates a vertex with given x and y coordinates for position and given tx and ty coordinates for the UV texture mapping for those points.
  • Creates a vertex with given x and y coordinates for both position and texture position.