Struct let_engine::error::textures::TextureIDError
source · pub struct TextureIDError;Expand description
This error gets returned when you set the texture ID of an Appearance object higher than the actual frame count of the texture this object is holding.