Macro let_engine::let_engine
source · macro_rules! let_engine {
() => { ... };
}Expand description
Initializes the let engine.
Creates 4 static variables that can be accessed everywhere to use.
INPUT: a live updated Input struct.
TIME: a live updated Time struct.
RESOURCES: The resource manager where you load your assets.
WINDOW: A Window that you can change the attributes of once you’ve run the crate::start_engine macro.