Module let_engine::objects

source ·
Objects to be drawn to the screen.

Modules

Structs

  • Holds everything about the appearance of objects like textures, vetex/index data, color and material.
  • Node structure for the layer.
  • Holds position size and rotation of an object.

Traits

  • The trait that automatically gets implemented to each object you give the object attribute.

Type Aliases