#[repr(transparent)]
pub struct PrismaticJoint { pub data: GenericJoint, }
A prismatic joint, locks all relative motion between two bodies except for translation along the joint’s principal axis.

Fields

data: GenericJoint

The underlying joint data.

Implementations

source

impl PrismaticJoint

source

pub fn new(axis: Vec2) -> Self

Creates a new prismatic joint allowing only relative translations along the specified axis.

This axis is expressed in the local-space of both rigid-bodies.

source

pub fn data(&self) -> &GenericJoint

The underlying generic joint.

source

pub fn contacts_enabled(&self) -> bool

Are contacts between the attached rigid-bodies enabled?

source

pub fn set_contacts_enabled(&mut self, enabled: bool) -> &mut Self

Sets whether contacts between the attached rigid-bodies are enabled.

source

pub fn local_anchor1(&self) -> Vec2

The joint’s anchor, expressed in the local-space of the first rigid-body.

source

pub fn set_local_anchor1(&mut self, anchor1: Vec2) -> &mut Self

Sets the joint’s anchor, expressed in the local-space of the first rigid-body.

source

pub fn local_anchor2(&self) -> Vec2

The joint’s anchor, expressed in the local-space of the second rigid-body.

source

pub fn set_local_anchor2(&mut self, anchor2: Vec2) -> &mut Self

Sets the joint’s anchor, expressed in the local-space of the second rigid-body.

source

pub fn local_axis1(&self) -> Vec2

The principal axis of the joint, expressed in the local-space of the first rigid-body.

source

pub fn set_local_axis1(&mut self, axis1: Vec2) -> &mut Self

Sets the principal axis of the joint, expressed in the local-space of the first rigid-body.

source

pub fn local_axis2(&self) -> Vec2

The principal axis of the joint, expressed in the local-space of the second rigid-body.

source

pub fn set_local_axis2(&mut self, axis2: Vec2) -> &mut Self

Sets the principal axis of the joint, expressed in the local-space of the second rigid-body.

source

pub fn motor(&self) -> Option<&JointMotor>

The motor affecting the joint’s translational degree of freedom.

source

pub fn set_motor_model(&mut self, model: MotorModel) -> &mut Self

Set the spring-like model used by the motor to reach the desired target velocity and position.

source

pub fn set_motor_velocity( &mut self, target_vel: Real, factor: Real ) -> &mut Self

Sets the target velocity this motor needs to reach.

source

pub fn set_motor_position( &mut self, target_pos: Real, stiffness: Real, damping: Real ) -> &mut Self

Sets the target angle this motor needs to reach.

source

pub fn set_motor( &mut self, target_pos: Real, target_vel: Real, stiffness: Real, damping: Real ) -> &mut Self

Configure both the target angle and target velocity of the motor.

source

pub fn set_motor_max_force(&mut self, max_force: Real) -> &mut Self

Sets the maximum force the motor can deliver.

source

pub fn limits(&self) -> Option<&JointLimits<Real>>

The limit distance attached bodies can translate along the joint’s principal axis.

source

pub fn set_limits(&mut self, limits: [Real; 2]) -> &mut Self

Sets the [min,max] limit distances attached bodies can translate along the joint’s principal axis.