Struct let_engine::objects::physics::joints::RopeJointBuilder
source · pub struct RopeJointBuilder(pub RopeJoint);Expand description
Create rope joints using the builder pattern.
A rope joint, limits the maximum distance between two bodies.
Tuple Fields
0: RopeJointImplementations
sourceimpl RopeJointBuilder
impl RopeJointBuilder
sourcepub fn new() -> Self
pub fn new() -> Self
Creates a new builder for rope joints.
This axis is expressed in the local-space of both rigid-bodies.
sourcepub fn contacts_enabled(self, enabled: bool) -> Self
pub fn contacts_enabled(self, enabled: bool) -> Self
Sets whether contacts between the attached rigid-bodies are enabled.
sourcepub fn local_anchor1(self, anchor1: Vec2) -> Self
pub fn local_anchor1(self, anchor1: Vec2) -> Self
Sets the joint’s anchor, expressed in the local-space of the first rigid-body.
sourcepub fn local_anchor2(self, anchor2: Vec2) -> Self
pub fn local_anchor2(self, anchor2: Vec2) -> Self
Sets the joint’s anchor, expressed in the local-space of the second rigid-body.
sourcepub fn local_axis1(self, axis1: Vec2) -> Self
pub fn local_axis1(self, axis1: Vec2) -> Self
Sets the principal axis of the joint, expressed in the local-space of the first rigid-body.
sourcepub fn local_axis2(self, axis2: Vec2) -> Self
pub fn local_axis2(self, axis2: Vec2) -> Self
Sets the principal axis of the joint, expressed in the local-space of the second rigid-body.
sourcepub fn motor_model(self, model: MotorModel) -> Self
pub fn motor_model(self, model: MotorModel) -> Self
Set the spring-like model used by the motor to reach the desired target velocity and position.
sourcepub fn motor_velocity(self, target_vel: Real, factor: Real) -> Self
pub fn motor_velocity(self, target_vel: Real, factor: Real) -> Self
Sets the target velocity this motor needs to reach.
sourcepub fn motor_position(
self,
target_pos: Real,
stiffness: Real,
damping: Real
) -> Self
pub fn motor_position( self, target_pos: Real, stiffness: Real, damping: Real ) -> Self
Sets the target angle this motor needs to reach.
sourcepub fn set_motor(
self,
target_pos: Real,
target_vel: Real,
stiffness: Real,
damping: Real
) -> Self
pub fn set_motor( self, target_pos: Real, target_vel: Real, stiffness: Real, damping: Real ) -> Self
Configure both the target angle and target velocity of the motor.
sourcepub fn motor_max_force(self, max_force: Real) -> Self
pub fn motor_max_force(self, max_force: Real) -> Self
Sets the maximum force the motor can deliver.