pub struct Label {
    pub transform: Transform,
    pub appearance: Appearance,
    pub font: Font,
    pub text: String,
    pub scale: Vec2,
    pub align: [f32; 2],
    /* private fields */
}
A Label object made to display text.

note

It is recommended to sync or update the text with all other visible labels so the texture of all labels change to the same texture. At the beginning of the game update all the text gets rendered if any labels changed. This produces a new texture which if not synced to every label produces multiple textures, which take more memory.

Fields

transform: Transformappearance: Appearancefont: Fonttext: Stringscale: Vec2align: [f32; 2]

Implementations

source

impl Label

source

pub fn new( resources: &Resources, font: &Font, create_info: LabelCreateInfo ) -> Self

Creates a new label with the given settings.

source

pub fn update(&mut self)

Updates the local information of this label from the layer, in case it has changed if for example the parent was changed too.

source

pub fn update_text(&mut self, text: String)

Changes the text of the label and updates it on the layer.

source

pub fn sync(&self)

Syncs the public layer side label to be the same as the current.