Macro let_engine::prelude::font
source · macro_rules! font { ($data:expr) => { ... }; }
Loads a font to the engine using binary true type font data of the inserted
&[u8] and returns a Font.
macro_rules! font { ($data:expr) => { ... }; }
Loads a font to the engine using binary true type font data of the inserted
&[u8] and returns a Font.