Struct let_engine::prelude::materials::Material
source · pub struct Material { /* private fields */ }Expand description
A material holding the way an object should be drawn.
Takes some time.
Implementations
sourceimpl Material
impl Material
sourcepub fn write(
&mut self,
descriptor: Vec<WriteDescriptorSet>,
allocator: &StandardDescriptorSetAllocator
)
pub fn write( &mut self, descriptor: Vec<WriteDescriptorSet>, allocator: &StandardDescriptorSetAllocator )
Writes to the material changing the variables for the shaders.
sourcepub fn set_layer(&mut self, id: u32) -> Result<(), Box<dyn Error>>
pub fn set_layer(&mut self, id: u32) -> Result<(), Box<dyn Error>>
Sets the layer of the texture in case it has a texture with layers.
pub fn get_layer(&self) -> u32
sourcepub fn next_frame(&mut self) -> Result<(), Box<dyn Error>>
pub fn next_frame(&mut self) -> Result<(), Box<dyn Error>>
Goes to the next frame of the layer.
Returns an error if it reached the limit.
sourcepub fn last_frame(&mut self) -> Result<(), Box<dyn Error>>
pub fn last_frame(&mut self) -> Result<(), Box<dyn Error>>
Goes to the last frame of the layer.
Returns an error if the layer is 0.
sourcepub fn get_texture(&self) -> Option<Texture>
pub fn get_texture(&self) -> Option<Texture>
Returns the texture.
sourcepub fn set_texture(&mut self, texture: Option<Texture>)
pub fn set_texture(&mut self, texture: Option<Texture>)
Sets the texture.