Struct let_engine::prelude::Node
source · pub struct Node<T> {
pub object: T,
pub parent: Option<Weak<Mutex<Node<Box<dyn GameObject>>>>>,
pub rigid_body_parent: RigidBodyParent,
pub children: Vec<Arc<Mutex<Node<T>>>>,
}Expand description
Node structure for the layer.
Fields
object: Tparent: Option<Weak<Mutex<Node<Box<dyn GameObject>>>>>rigid_body_parent: RigidBodyParentchildren: Vec<Arc<Mutex<Node<T>>>>Implementations
sourceimpl Node<Box<dyn GameObject>>
impl Node<Box<dyn GameObject>>
sourcepub fn update_children_position(&mut self, parent_pos: Transform)
pub fn update_children_position(&mut self, parent_pos: Transform)
Iterates to the last child to update all public position held by the Node.
sourcepub fn remove_child(&mut self, object: &NObject)
pub fn remove_child(&mut self, object: &NObject)
Searches for the given object to be removed from the list of children.
sourcepub fn remove_children(
&mut self,
objects: &mut HashMap<usize, NObject>,
rigid_bodies: &mut HashMap<usize, NObject>
)
pub fn remove_children( &mut self, objects: &mut HashMap<usize, NObject>, rigid_bodies: &mut HashMap<usize, NObject> )
Removes all children and their children from the layer.
sourcepub fn end_transform(&self) -> Transform
pub fn end_transform(&self) -> Transform
Returns the public transform of this objects.