Module let_engine::resources::materials
source · Expand description
Material related settings that determine the way the scene gets rendered.
Structs
- A material holding the way an object should be drawn.
- Vertex and fragment shaders of a material as well as the topology and line width, if the topology is set to LineList or LineStrip.
- Builder for
MaterialSettings. - Holds compiled shaders in form of ShaderModules to use in a material.
Enums
- Error type for MaterialSettingsBuilder
- The way in which an object gets drawn using it’s vertices and indices.