Enum let_engine::resources::sounds::PlaybackRate
source · pub enum PlaybackRate {
Factor(f64),
Semitones(f64),
}Expand description
How quickly a sound is played.
Variants
Factor(f64)
The sound is played at a speed factor of the original playback rate.
For example, PlaybackRate::Factor(2.0) means
the sound is played twice as fast as normal.
Semitones(f64)
The sound is played faster or slower so that the pitch of the sound is adjusted by the given number of semitones.
Implementations
sourceimpl PlaybackRate
impl PlaybackRate