Struct let_engine::resources::sounds::AudioSettings
source · pub struct AudioSettings {
pub sound_capacity: usize,
pub object_bound_sound_capacity: usize,
pub spatial_scene_capacity: usize,
}Expand description
The global audio settings that should be used throughout the game.
Fields
sound_capacity: usizeThe limit of how many sounds can exist at the same time.
object_bound_sound_capacity: usizeThe limit of how many sounds can be bound to objects to make them spatial.
spatial_scene_capacity: usizeThe limit of how many scenes can play spatial sounds.
Implementations
sourceimpl AudioSettings
impl AudioSettings
sourcepub fn set_sound_capacities(&mut self, sound_capacity: usize)
pub fn set_sound_capacities(&mut self, sound_capacity: usize)
Sets the maximum amount of sounds.
sourcepub fn sound_capacity(self, sound_capacity: usize) -> Self
pub fn sound_capacity(self, sound_capacity: usize) -> Self
Sets the maximum amount of sounds and returns self.
sourcepub fn set_object_bound_sound_capacity(&mut self, sound_capacity: usize)
pub fn set_object_bound_sound_capacity(&mut self, sound_capacity: usize)
Sets the maximum amount of sounds you can bind on objects to make them spatial.
sourcepub fn object_bound_sound_capacity(self, sound_capacity: usize) -> Self
pub fn object_bound_sound_capacity(self, sound_capacity: usize) -> Self
Sets the maximum amount of sounds you can bind on objects to make them spatial and returns self.
sourcepub fn set_spatial_scene_capacity(&mut self, scene_capacity: usize)
pub fn set_spatial_scene_capacity(&mut self, scene_capacity: usize)
Sets the maximum amount of scenes that can play spatial sounds.
sourcepub fn spatial_scene_capacity(self, scene_capacity: usize) -> Self
pub fn spatial_scene_capacity(self, scene_capacity: usize) -> Self
Sets the maximum amount of scenes that can play spatial sounds and returns self.