pub struct SoundSettings {
    pub playback_region: Region,
    pub loop_region: Option<Region>,
    pub reverse: bool,
    pub volume: Volume,
    pub playback_rate: PlaybackRate,
    pub panning: f64,
    pub fade_in_tween: Option<Tween>,
}
Settings that determine the appearance of the sound.

Fields

playback_region: Region

The portion of the sound that should be played.

loop_region: Option<Region>

The portion of the sound that should be looped.

reverse: bool

Whether the sound should be played in reverse.

volume: Volume

The volume of the sound.

playback_rate: PlaybackRate

The rate at which the sound should be played.

Changes both speed and pitch of the sound.

panning: f64

The panning of the sound. 0 is left, 1 is right.

fade_in_tween: Option<Tween>

An optional fade in.

Implementations

source

impl SoundSettings

source

pub fn new() -> Self

source

pub fn playback_region(self, playback_region: impl Into<Region>) -> Self

Sets the playback region and returns self.

source

pub fn loop_region(self, loop_region: impl Into<Option<Region>>) -> Self

Sets the optional loop region and returns self.

source

pub fn reverse(self, reverse: impl Into<bool>) -> Self

Sets whether this sound plays reverse and returns self.

source

pub fn volume(self, volume: impl Into<Volume>) -> Self

Sets the volume and returns self.

source

pub fn playback_rate(self, playback_rate: impl Into<PlaybackRate>) -> Self

Sets the playback rate and returns self.

source

pub fn panning(self, panning: impl Into<f64>) -> Self

Sets the panning and returns self.

source

pub fn fade_in_tween(self, fade_in_tween: impl Into<Option<Tween>>) -> Self

Sets the fade in tween and returns self.