Module let_engine::resources::textures
source · Expand description
Texture related options.
Structs
- The sampler of the texture that determines how the shader should handle textures.
- Builder for
Sampler. - A texture to be used with materials.
- The main texture settings.
Enums
- Handling of pixels outside the position range of the texture.
- The color to use for the border of an image.
- Filtering mode
- Formats for the texture from raw data.
- An enumeration of supported image formats. Not all formats support both encoding and decoding.
- Error type for SamplerBuilder