Module let_engine::window

source ·

Modules

  • UI scaling is important, so read the docs for this module if you don’t want to be confused.

Structs

  • An icon used for the window titlebar, taskbar, etc.
  • A struct representing the window.
  • A builder describing the initial state of the window.

Enums