Module let_engine::error::objects
source · Expand description
Object and layer related errors. Object based errors.
Structs
- This error gets returned when the layer that gets specified when an object needs to get added doesn’t exit in the objects list anymore.
- This error gets returned when the game can’t find a matching object in the game object list as the object that got input as a parent.
- This error gets returned when the parent of the object that wants to get added isn’t in the game object list anymore.
- This error gets returned when one of the objects input into register_joint doesn’t have a rigid body to attach the joint to.