Module let_engine::error::textures
source · Expand description
Texture related errors. Object based errors.
Structs
- This error gets returned when you give the wrong format to the texture when trying to create a new texture.
- This error gets returned when a function gets called that requires an object to have a texture but it does not have one.
- This error gets returned when you set the texture ID of an Appearance object higher than the actual frame count of the texture this object is holding.