Module let_engine::objects
source · Expand description
Objects to be drawn to the screen.
Modules
- Default labels given by the engine.
- Physics related structs.
Structs
- Holds everything about the appearance of objects like textures, vetex/index data, color and material.
- Node structure for the layer.
- Holds position size and rotation of an object.
Traits
- The trait that automatically gets implemented to each object you give the object attribute.