Module let_engine::resources
source · Expand description
Resources to be handled by the engine like textures, sounds and fonts.
Modules
- Holds model related data structures like Vertices and premade models as well as a circle maker macro.
- Material related settings that determine the way the scene gets rendered.
- Texture related options.
Macros
- Loads a font to the engine using binary true type font data of the inserted
&[u8]and returns a Font. - Loads a new material.
- Loads a shader from glsl bytes. Takes
&[u8]and returns Shaders. Those shaders can be used when making materials. - Loads a texture to the engine using one of the supported file formats and returns a Texture.
- Loads a texture to the engine using raw image bytes and context and returns a Texture.
- Describes a write operation for a descriptor. Used with materials to interact with custom shaders inside them.
Structs
- A font to be used with the default label system.
- The model of an object made of vertices and indices.
- All the resources kept in the game engine like textures, fonts, sounds and models.
- A texture to be used with materials.
Functions
- Not done.