Struct let_engine::resources::sounds::SoundSettings
source · pub struct SoundSettings {
pub playback_region: Region,
pub loop_region: Option<Region>,
pub reverse: bool,
pub volume: Volume,
pub playback_rate: PlaybackRate,
pub panning: f64,
pub fade_in_tween: Option<Tween>,
}Expand description
Settings that determine the appearance of the sound.
Fields
playback_region: RegionThe portion of the sound that should be played.
loop_region: Option<Region>The portion of the sound that should be looped.
reverse: boolWhether the sound should be played in reverse.
volume: VolumeThe volume of the sound.
playback_rate: PlaybackRateThe rate at which the sound should be played.
Changes both speed and pitch of the sound.
panning: f64The panning of the sound. 0 is left, 1 is right.
fade_in_tween: Option<Tween>An optional fade in.
Implementations
sourceimpl SoundSettings
impl SoundSettings
pub fn new() -> Self
sourcepub fn playback_region(self, playback_region: impl Into<Region>) -> Self
pub fn playback_region(self, playback_region: impl Into<Region>) -> Self
Sets the playback region and returns self.
sourcepub fn loop_region(self, loop_region: impl Into<Option<Region>>) -> Self
pub fn loop_region(self, loop_region: impl Into<Option<Region>>) -> Self
Sets the optional loop region and returns self.
sourcepub fn reverse(self, reverse: impl Into<bool>) -> Self
pub fn reverse(self, reverse: impl Into<bool>) -> Self
Sets whether this sound plays reverse and returns self.
sourcepub fn playback_rate(self, playback_rate: impl Into<PlaybackRate>) -> Self
pub fn playback_rate(self, playback_rate: impl Into<PlaybackRate>) -> Self
Sets the playback rate and returns self.
sourcepub fn fade_in_tween(self, fade_in_tween: impl Into<Option<Tween>>) -> Self
pub fn fade_in_tween(self, fade_in_tween: impl Into<Option<Tween>>) -> Self
Sets the fade in tween and returns self.