Texture related options.

Structs

Enums

  • Handling of pixels outside the position range of the texture.
  • The color to use for the border of an image.
  • Filtering mode
  • Formats for the texture from raw data.
  • An enumeration of supported image formats. Not all formats support both encoding and decoding.
  • Error type for SamplerBuilder